@@ -1,5 +1,5 @@
 ;;; GNU Guile-RPC --- A Scheme implementation of ONC RPC.
-;;; Copyright (C) 2007  Free Software Foundation, Inc.
+;;; Copyright (C) 2007, 2010  Free Software Foundation, Inc.
 ;;;
 ;;; This file is part of GNU Guile-RPC.
 ;;;
@@ -24,8 +24,8 @@
              (rpc xdr)
              (rpc xdr types)
              (srfi srfi-4)
-             (r6rs bytevector)
-             (r6rs io ports))
+             (rnrs bytevectors)
+             (rnrs io ports))
 
 (define vec
   (make-u8vector 12312))
