@@ -1,5 +1,5 @@
-;;; GNU Guile-RPC --- A Scheme implementation of ONC RPC.
-;;; Copyright (C) 2008  Free Software Foundation, Inc.
+;;; GNU Guile-RPC --- A Scheme implementation of ONC RPC.  -*- coding: utf-8 -*-
+;;; Copyright (C) 2008, 2010, 2012  Free Software Foundation, Inc.
 ;;;
 ;;; This file is part of GNU Guile-RPC.
 ;;;
@@ -45,7 +45,7 @@
            compiler-duplicate-identifier-error:name
            compiler-duplicate-identifier-error:previous-location))
 
-;;; Author: Ludovic Courts <ludo@gnu.org>
+;;; Author: Ludovic Courtès <ludo@gnu.org>
 ;;;
 ;;; Commentary:
 ;;;
@@ -74,16 +74,6 @@
   (name               compiler-duplicate-identifier-error:name)
   (previous-location  compiler-duplicate-identifier-error:previous-location))
 
-
-;;;
-;;; Workarounds.
-;;;
-
-;; Work around missing export in `(ice-9 match)' in Guile 1.8.4 and earlier.
-(if (not (defined? 'match:andmap))
-    (define match:andmap (@@ (ice-9 match) match:andmap)))
-
-
 
 ;;;
 ;;; Compilation context (environment).
@@ -698,14 +688,14 @@ form, e.g., one with dashed instead of underscores, etc."
                            `(define ,(make-procedure-name name)
                               (make-synchronous-rpc-call
                                ,program-number ,version-number ,number
-                               ,ret-type
                                ,(cond ((null? arg-types)
                                        'xdr-void)
                                       ((null? (cdr arg-types))
                                        (car arg-types))
                                       (else
                                        `(make-xdr-struct-type
-                                         (list ,@arg-types))))))))
+                                         (list ,@arg-types))))
+                               ,ret-type))))
                        (reverse procs))))
               (reverse versions)))
 
@@ -802,6 +792,7 @@ form, e.g., one with dashed instead of underscores, etc."
              ("float"            (define xdr-float ...) #f)
              ("double"           (define xdr-double ...) #f)
              ;; FIXME: We lack support for `quadruple'.
+             ("string"           (define xdr-string ...) #f)
              )
            '()
            '()
@@ -966,9 +957,4 @@ form, e.g., one with dashed instead of underscores, etc."
                                 (cons name type))))
                        (context-types output)))))))
 
-
-;;; Local Variables:
-;;; coding: latin-1
-;;; End:
-
 ;;; compiler.scm ends here
