@@ -1,5 +1,5 @@
-;;; GNU Guile-RPC --- A Scheme implementation of ONC RPC.
-;;; Copyright (C) 2007  Free Software Foundation, Inc.
+;;; GNU Guile-RPC --- A Scheme implementation of ONC RPC.  -*- coding: utf-8 -*-
+;;; Copyright (C) 2007, 2010  Free Software Foundation, Inc.
 ;;;
 ;;; This file is part of GNU Guile-RPC.
 ;;;
@@ -21,7 +21,7 @@
   :use-module (rpc rpc types)
   :use-module (srfi srfi-34)
   :use-module (srfi srfi-35)
-  :use-module (r6rs bytevector)
+  :use-module (rnrs bytevectors)
   :use-module (ice-9 optargs)
   :autoload   (rpc rpc transports) (send-rpc-record
                                     rpc-record-marking-input-port)
@@ -52,7 +52,7 @@
            rpc-system-error?
            rpc-authentication-error?))
 
-;;; Author: Ludovic Courts <ludo@gnu.org>
+;;; Author: Ludovic Courtès <ludo@gnu.org>
 ;;;
 ;;; Commentary:
 ;;;
@@ -294,8 +294,4 @@ condition is raised."
              (xdr-decode result-type endpoint))))))
 
 
-;;; Local Variables:
-;;; coding: latin-1
-;;; End:
-
 ;;; rpc.scm ends here
